program jcCleanOMP
  ! Program to replace nans with zeros
  ! Purpose is so that you don't need to remove nans manually--just replace with zeros since they won't effect stack
  ! However, there amplitude will be effected when normalizing the amplitude by number of traces
  ! Input:
  !   1) history file (will not handle header history files)
  !
  ! Output:
  !   1) history file with zeros now

  use sep
  implicit none

  ! declare variables
  integer                                 :: ii
  integer                                 :: n1,n2,n3,n4
  real,allocatable,dimension (:)          :: tot
  real,allocatable,dimension (:,:)        :: datain

  ! open I/O
  call sep_init()

  call from_history('n1',n1, 1)
  call from_history('n2',n2, 1)
  call from_history('n3',n3, 1)
  call from_history('n4',n4, 1)

  call sep_close()

  ! allocate
  allocate(datain(n1,n2))
  allocate(tot(n2))

  ! read in
  call sreed('in',datain,4*n1*n2)

  ! loop over all source-receiver combos
  !$OMP PARALLEL DO default(shared) private(ii)
  do ii=1,n2*n3
    tot(ii) = sum(datain(:,ii))
    if ( isnan(tot(ii)) ) datain(:,ii) = 0.
  end do
  !$OMP END PARALLEL DO

  ! write out
  call srite('out',datain,4*n1*n2)

  ! clean up
  deallocate(datain)

end program
