program jcReattachHeader
  ! Program to take sorted and stacked output and attached proper header to it
  ! NEED TO EXTEND THIS TO MULTIPLE SOURCES
  !
  ! Inputs:
  !   1) history file (sorted, stacked correlations)
  !   2) header history file with proper coordinates
  !   3) index of line and point in the header file
  !
  ! Outputs:
  !   1) trimmed history file
  !   2) synched header file (xy_out)

  use sep
  implicit none

  ! declare variables
  integer                           :: ii,jj,kk
  integer                           :: n1,n2,n3
  integer                           :: n1xy,n2xy
  integer                           :: iline,ipoint,ntraces
  integer,allocatable,dimension (:) :: line,point
  real                              :: d1,d2,d3,o1,o2,o3
  real                              :: tot
  real,allocatable,dimension (:)    :: datain
  real,allocatable,dimension (:,:)  :: headerin
  logical                           :: found

  ! open I/O
  call sep_init()

  call from_history('n1',n1,1 ) !lag time
  call from_history('o1',o1,1.)
  call from_history('d1',d1,1.)
  call from_history('n2',n2,1 ) !receiverLine
  call from_history('o2',o2,1.)
  call from_history('d2',d2,2.)
  call from_history('n3',n3,1 ) !receiverPoint
  call from_history('o3',o3,1.)
  call from_history('d3',d3,2.)


  ! read in the header file
  if (exist_file("xy_in")) then
    call from_param('iline' ,iline ,3)
    call from_param('ipoint',ipoint,4)
    call from_aux('xy_in','n1',n1xy)
    call from_aux('xy_in','n2',n2xy)
  else
    call seperr("Need header file for the correlations")
  end if

  ! allocate
  allocate(datain(n1))
  allocate(headerin(n1xy,n2xy))
  allocate(line(n2))
  allocate(point(n3))
  ntraces=0

  ! precompute line and point values
  do jj=1,n2
    line(jj) = o2+(jj-1)*d2
  end do
  do ii=1,n3
    point(ii) = o3+(ii-1)*d3
  end do

  ! read in header info
  call sreed("xy_in",headerin,4*n1xy*n2xy)

  do ii=1,n3
    do jj=1,n2

      ! read in data
      call sreed("in",datain,4*n1)

      ! check if line is empty
      tot = sum(datain)

      if ( tot.ne.0. ) then
        ntraces = ntraces+1
        ! read out
        call srite("out",datain,4*n1)

        ! find the associated header (can stop after you find correct info)
        found = .false.
        do kk=1,n2xy
          if ( (headerin(iline,kk).eq.line(jj)).and.(headerin(ipoint,kk).eq.point(ii)).and.(.not.found) ) then
            call srite("xy_out",headerin(:,kk),4*n1xy)
            found = .true.
          end if
        end do
      end if

    end do
  end do


  ! still need to figure out dimensions at end
  call to_history('n1',n1)
  call to_history('o1',o1)
  call to_history('d1',d1)
  call to_history('n2',ntraces) !number of receivers
  call to_history('o2',0.)
  call to_history('d2',1.)
  call to_history('n3',1.) !number of sources
  call to_history('o3',0.)
  call to_history('d3',1.)

  if ( exist_file('xy_out') ) then
    call to_history('n1',n1xy   ,'xy_out')
    call to_history('n2',ntraces,'xy_out')
  end if
  
  call sep_close()

  ! clean up
  deallocate(datain,headerin,line,point)
end program
