program jcTauP
  ! Jason Chang
  ! May 2013
  !
  ! Tau-P transform in 1D
  !	- perform Tau-P transfrom on seismic gathers
  !	- should be able to pull out slownesses
  !	- works for only regular SEP datasets
  !
  ! Input:
  !	- seismic gathers (n1:time, n2:space)
  !
  ! Output:
  !	- Tau-P transform

  use sep
  implicit none

  ! declare variables
  integer                                :: ii,it,ipx,itau,ix
  integer                                :: nt,nx,ntau,npx
  real                                   :: dt,ot,dtau,otau,dx,ox,pxmin,pxmax,dpx,opx,tau
  real,allocatable,dimension (:)         :: time,px,x
  real,allocatable,dimension (:,:)       :: dat,mod

  ! open I/O
  call sep_init()

  ! history file variables
  call from_history('n1',nt,1 )
  call from_history('o1',ot,1.)
  call from_history('d1',dt,1.)
  call from_history('n2',nx,1 )
  call from_history('o2',ox,1.)
  call from_history('d2',dx,1.)

  ! tau-p variables
  call from_param("ntau" ,ntau  ,nt                  )
  call from_param("dtau" ,dtau  ,dt                  )
  call from_param("otau" ,otau  ,ot                  )
  call from_param("pxmin",pxmin,-1./500.             )
  call from_param("pxmax",pxmax, 1./500.             )
  call from_param("npx"  ,npx  ,int(sqrt(real(nx)))  )
  call from_param("dpx"  ,dpx  ,(pxmax-pxmin)/(npx-1))
  call from_param("opx"  ,opx  ,pxmin                )

  ! out to history file
  call to_history('n1',ntau)
  call to_history('d1',dtau)
  call to_history('o1',otau)
  call to_history('n2',npx )
  call to_history('d2',dpx )
  call to_history('o2',opx )

  call to_history('label1','tau')
  call to_history('label2','p'  )

  call sep_close()

  ! allocate
  allocate(dat(nt,nx))
  allocate(mod(ntau,npx))
  allocate(time(nt))
  allocate(px(npx))
  allocate(x(nx))

  ! set up time, slowness, position vectors outside of loop
  do ii=1,nt
    time(ii) = ot+(ii-1)*dt
  end do
  do ii=1,npx
    px(ii) = opx+(ii-1)*dpx
  end do
  do ii=1,nx
    x(ii) = ox+(ii-1)*dx
  end do

  ! read in data
  call sreed('in',dat,4*nt*nx)

  ! kernel
  do ipx=1,npx
    do it=1,nt
      do ix=1,nx
        tau = time(it)-(px(ipx)*x(ix))
        itau = 1.5 + (tau-otau)/dtau
        if (itau.ge.1 .and. itau.le.ntau) then
          mod(itau,ipx) = mod(itau,ipx) + dat(it,ix)
        end if
      end do
    end do
  end do

  ! write out data
  call srite('out',mod,4*ntau*npx)

  ! clean up
  deallocate(dat,mod,time,px,x)

end program
