program jcWindowStation
  ! Program to find and window a given set of stations for correlations
  ! Necessary where station locations are not index the same way from station to station
  ! Make it work for one station only first (might be better if you correlate everything, then expand the headers to sort later)
  ! Only takes the first station with the proper line and point coordinates
  !
  ! Inputs:
  !   1) history file
  !   2) header file
  !   3) station line and point coordinates
  !
  ! Output:
  !   1) history file
  !   2) header file (opt)

  use sep
  implicit none

  ! declare variables
  integer                                 :: ii
  integer                                 :: n1,n2
  integer                                 :: n1xy,n2xy
  integer                                 :: iline,ipoint
  integer                                 :: line,point
  real,allocatable,dimension (:,:)        :: datain,headerin

  ! open I/O
  call sep_init()

  ! read in history file parameters
  call from_history('n1',n1,1)
  call from_history('n2',n2,1)

  ! check the header file parameters
  if (exist_file ('xy_in')) then
    call from_param('iline' ,iline ,3)
    call from_param('ipoint',ipoint,4)
    call from_aux('xy_in','n1',n1xy  )
    call from_aux('xy_in','n2',n2xy  )
    if ( n2.ne.n2xy ) call erexit ("n2 and n2xy do not match")
  else
    call erexit("Need xy_in header file")
  end if

  ! specify the line and point you want
  call from_param('line' ,line ,1)
  call from_param('point',point,1)

  ! write out parameters
  call to_history('n1',n1)
  call to_history('n2',1 )

  if (exist_file ('xy_out')) then
    call to_history('n1',n1xy,'xy_out')
    call to_history('n2',1   ,'xy_out')
  end if

  call sep_close()

  ! allocate
  allocate(datain(n1,n2))
  allocate(headerin(n1xy,n2xy))

  ! read in
  call sreed("in"   ,datain  ,4*n1*n2    )
  call sreed("xy_in",headerin,4*n1xy*n2xy)

  do ii=1,n2
    if ( (headerin(iline,ii).eq.line).and.(headerin(ipoint,ii).eq.point) ) then
      call srite("out",datain(:,ii),4*n1)
      if (exist_file ('xy_out')) call srite("xy_out",headerin(:,ii),4*n1xy)
      exit
    end if
  end do

  ! clean up
  deallocate(datain,headerin)

end program
